@@ -7,7 +7,7 @@ See :doc:`/plugins/bevats`.
    :toctree:
 
     models
-    desktop
+    ui
     fixtures.std
     fixtures.payments
 
