@@ -29,10 +29,10 @@ class Plugin(ad.Plugin):
         super(Plugin, self).post_site_startup(site)
         self.client_model = site.models.resolve(self.client_model)
 
-        if site.is_installed('memo'):
-            rdm = site.plugins.memo.parser.register_django_model
-            rdm('client', self.client_model,
-                title=lambda obj: obj.get_full_name())
+        # if site.is_installed('memo'):
+        #     rdm = site.plugins.memo.parser.register_django_model
+        #     rdm('client', self.client_model,
+        #         title=lambda obj: obj.get_full_name())
 
     def before_analyze(self):
         super(Plugin, self).before_analyze()
