@@ -723,6 +723,17 @@ class Role(dd.Model, Addressable):
             return str(self.person)
         return "%s (%s)" % (self.person, self.type)
 
+    def as_paragraph(self, ar):
+        if ar.is_obvious_field('person'):
+            txt = ar.obj2str(self.company)
+        elif ar.is_obvious_field('company'):
+            txt = ar.obj2str(self.person)
+        else:
+            return super().__str__()
+        if self.type is not None:
+            txt = "{} ({})".format(txt, self.type)
+        return txt
+
     def address_person_lines(self):
         if self.company:
             for ln in self.company.address_person_lines():
