@@ -5,7 +5,7 @@ from django.db import models
 
 from lino.modlib.users.mixins import UserAuthored
 from lino_xl.lib.cal.models import Calendar, BaseSubscription, Event
-from lino.api import dd, _
+from lino.api import rt, dd, _
 
 from .utils import get_resource, map_calendar_into_dbModel, map_event_into_dbModel
 
@@ -73,8 +73,8 @@ def sync_user_calendar(user):
 
             user_s_cal, _ = UserSubscriptionToCalendar.objects.get_or_create(
                 calendar=calendar, user=user)
-            user_s_cal.is_hidden = cal.get('hidden')
-            user_s_cal.user_access_role=cal.get('accessRole')
+            user_s_cal.is_hidden = cal.get('hidden', False)
+            user_s_cal.user_access_role = cal.get('accessRole')
             user_s_cal.full_clean()
             user_s_cal.save()
 
