@@ -79,7 +79,7 @@ def get_resource(user: User):
 def map_calendar_into_dbModel(cls, cal):
     calendar, _ = cls.objects.get_or_create(google_id=cal.get('id'))
     calendar.name=cal.get('summary')
-    calendar.description=cal.get('description')
+    calendar.description=cal.get('description', "")
     calendar.time_zone=cal.get('timeZone')
     return calendar
 
@@ -87,12 +87,12 @@ def map_event_into_dbModel(cls, event, user_s_cal):
     e, _ = cls.objects.get_or_create(
         google_id=event['id'], google_calendar=user_s_cal.calendar)
     e.status = event.get('status') # possible values are 'confirmed', 'tentative', 'cancelled'
-    e.summary = event.get('summary') # The title of the event
-    e.description = event.get('description')
-    e.sequence = event.get('sequence')
+    e.summary = event.get('summary', "") # The title of the event
+    e.description = event.get('description', "")
+    e.sequence = event.get('sequence', 0)
 
     def resolve_datetime(stamp):
-        return timezone.make_naive(parse(stamp))
+        return timezone.make_aware(timezone.make_naive(parse(stamp)))
 
     def resolve_date_time(stamp):
         dt = resolve_datetime(stamp)
