@@ -1,10 +1,10 @@
 import codecs
 import datetime
-from unipath import Path
+from pathlib import Path
 from lino.utils import AttrDict
 from lino.api import rt
 
-fn = Path(__file__).parent.child('tractickets.tsv')
+fn = Path(__file__).parent / 'tractickets.tsv'
 # http://trac.lino-framework.org/query?status=accepted&status=assigned&status=closed&status=new&status=reopened&col=id&col=summary&col=status&col=owner&col=type&col=priority&col=milestone&col=component&col=severity&col=resolution&col=time&col=changetime&col=reporter&order=id
 
 
@@ -90,7 +90,7 @@ def objects():
 # from lino.api import dd
 
 # server = xmlrpclib.ServerProxy(dd.plugins.lino_noi.trac_url)
-         
+
 # multicall = xmlrpclib.MultiCall(server)
 # for ticket in server.ticket.query("owner=luc"):
 #     multicall.ticket.get(ticket)
