@@ -460,6 +460,9 @@ class QtyVatItemBase(VatItemBase):
             else:
                 self.set_amount(ar, myround(self.unit_price * self.qty))
 
+# QtyVatItemBase.set_widget_options('qty', hide_sum=True)
+QtyVatItemBase.set_widget_options('unit_price', hide_sum=True)
+
 
 ledger = dd.resolve_app("ledger")
 
