@@ -111,6 +111,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
 
         return "%s # %s" % (self._meta.verbose_name, self.pk)
 
+    def as_paragraph(self, ar):
+        txt = ar.add_detail_link(self, str(self))
+        if not ar.is_obvious_field('ticket'):
+            txt += _(" working on ") + ar.obj2str(self.get_ticket())
+        return txt
+
     def get_ticket(self):
         return self.ticket
 
@@ -171,11 +177,11 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         return duration
 
     def get_sub_sessions(self):
-        if self.end_date == self.start_date:
+        if self.end_date is None or self.end_date == self.start_date:
             # print("20230117 single-day")
             qs = self.__class__.objects.filter(
                 user=self.user,
-                start_date=self.start_date, end_date=self.end_date,
+                start_date=self.start_date, end_date=self.start_date,
                 start_time__gte=self.start_time, end_time__lte=self.end_time)
             qs = qs.exclude(id=self.id)
             return qs
@@ -250,6 +256,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         if self.ticket_id and self.ticket.order_id:
             return self.ticket.order.get_invoiceable_partner()
 
+    def get_invoiceable_start_date(self, max_date):
+        return self.start_date
+
+    def get_invoiceable_end_date(self):
+        return self.end_date
+
     def get_invoiceable_product(self, max_date=None):
         par = self.get_invoiceable_partner()
         # par = self.project
@@ -288,11 +300,12 @@ class Session(UserAuthored, Started, Ended, Workable, InvoiceGenerator):
         if plan.order is not None:
             # raise Exception("20210731 {}".format(dd.plugins.invoicing.order_model))
             # qs = qs.filter(**gfk2lookup(cls.owner, plan.order))
-            if dd.plugins.invoicing.order_model is rt.models.orders.Order:
-                qs = qs.filter(ticket__order=plan.order)
-            else:
-                # sessions on a ticket without an order will never get invoiced
-                return []
+            qs = qs.filter(ticket__order=plan.order)
+            # if dd.plugins.invoicing.order_model is rt.models.orders.Order:
+            #     qs = qs.filter(ticket__order=plan.order)
+            # else:
+            #     # sessions on a ticket without an order will never get invoiced
+            #     return []
         else:
             qs = qs.filter(ticket__order__isnull=False)
 
