@@ -149,7 +149,8 @@ class Sessions(dd.Table):
             qs = qs.filter(ticket__site=pv.site)
 
         if pv.company:
-            qs = qs.filter(ticket__site__company=pv.company)
+            # qs = qs.filter(ticket__site__company=pv.company)
+            qs = qs.filter(ticket__order__partner=pv.company)
             # if dd.is_installed('deploy'):
             #     qs = qs.filter(
             #         ticket__deployments_by_ticket__milestone__room__company=pv.company)
@@ -451,14 +452,18 @@ class SessionsByReport(Sessions, DurationReport):
         mi = ar.master_instance
         if mi is None:
             return
-        spv = dict(start_date=mi.start_date, end_date=mi.end_date)
+        if False:
+            spv = dict(start_date=mi.start_date, end_date=mi.end_date)
+            spv.update(user=mi.user)
+        else:
+            spv = dict(start_date=mi.invoicing_min_date, end_date=mi.invoicing_max_date)
         # spv = mi.get_tickets_parameters()
         spv.update(company=mi.company)  # interesting_for
         spv.update(observed_event=dd.PeriodEvents.started)
-        spv.update(user=mi.user)
         ar.param_values.update(spv)
 
         qs = super().get_request_queryset(ar)
+        # print("20230205", qs.query)
         for obj in qs:
             load_sessions(obj, [obj])
             # obj._invested_time = compute_invested_time(
@@ -702,6 +707,16 @@ class WorkedHours(DaysTable, dd.VentilatingTable):
         # return list(reversed(lst))
         return reversed(list(super(WorkedHours, cls).get_data_rows(ar)))
 
+    @classmethod
+    def row_as_paragraph(cls, ar, row):
+        txt = ar.add_detail_link(row, str(row))
+        tickets = [
+            ar.obj2str(t, "#{0}".format(t.id), title=t.summary)
+            for t in row._tickets]
+        if len(tickets) > 0:
+            txt += " ({})".format(", ".join(tickets))
+        return txt
+
     @dd.displayfield(_("Worked tickets"))
     def worked_tickets(self, obj, ar):
         # pv = dict(start_date=obj.day, end_date=obj.day)
@@ -725,7 +740,7 @@ class WorkedHours(DaysTable, dd.VentilatingTable):
 
     @classmethod
     def param_defaults(cls, ar, **kw):
-        kw = super(WorkedHours, cls).param_defaults(ar, **kw)
+        kw = super().param_defaults(ar, **kw)
         kw.update(start_date=dd.today(-6))
         kw.update(end_date=dd.today())
         kw.update(user=ar.get_user())
